@@ -61,7 +61,7 @@ void LogViewExport::sendMail()
 
     int i = 0;
     QTreeWidgetItemIterator it(logViewWidget, QTreeWidgetItemIterator::Selected);
-    while (*it != NULL) {
+    while (*it != nullptr) {
         LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
 
         body += item->logLine()->exportToText();
@@ -139,13 +139,13 @@ void LogViewExport::printSelection()
     int movement = 0;
 
     QTreeWidgetItemIterator it(logViewWidget, QTreeWidgetItemIterator::Selected);
-    while (*it != NULL) {
+    while (*it != nullptr) {
         LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
         QString body = item->logLine()->exportToText();
         painter.setPen(originalPen);
         painter.drawText(printView, Qt::AlignLeft | Qt::TextWordWrap, body);
         int fontHeight = painter.fontMetrics().height();
-        int lines = painter.fontMetrics().width(body) / printView.width() + 1;
+        int lines = painter.fontMetrics().boundingRect(body).width() / printView.width() + 1;
         int moveBy = (fontHeight + 2) * lines;
         painter.translate(0, moveBy);
         movement = movement + moveBy;
@@ -171,7 +171,7 @@ void LogViewExport::printPageNumber(QPainter &painter, QRect &printView, int mov
     painter.translate(0, -movement);
     printView.moveTo(QPoint(0, printView.height()));
     painter.translate(0, -printView.height());
-    painter.drawText(printView.right() - painter.fontMetrics().width(QString::number(page)),
+    painter.drawText(printView.right() - painter.fontMetrics().boundingRect(QString::number(page)).width(),
                      printView.bottom() + painter.fontMetrics().ascent() + 5, QString::number(page));
 }
 
@@ -183,7 +183,7 @@ void LogViewExport::copyToClipboard()
     QString text;
 
     QTreeWidgetItemIterator it(logViewWidget, QTreeWidgetItemIterator::Selected);
-    while (*it != NULL) {
+    while (*it != nullptr) {
         LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
 
         // Copy the item content to the text string
@@ -216,7 +216,7 @@ void LogViewExport::fileSave()
     QTreeWidgetItemIterator it(logViewWidget, QTreeWidgetItemIterator::Selected);
 
     // No item selected
-    if (*it == NULL) {
+    if (*it == nullptr) {
         emit statusBarChanged(i18n("No items selected. Please select items to be able to save them."));
         return;
     }
@@ -234,7 +234,7 @@ void LogViewExport::fileSave()
 
         int nbCopied = 0;
 
-        while (*it != NULL) {
+        while (*it != nullptr) {
             LogViewWidgetItem *item = static_cast<LogViewWidgetItem *>(*it);
 
             // Copy the item content to the stream
