@@ -48,14 +48,14 @@ public:
     KComboBox *filterList();
     LogViewWidgetSearchLine *filterLine();
 
-public slots:
+public Q_SLOTS:
     void updateFilterColumns(const LogViewColumns &list);
 
-private slots:
+private Q_SLOTS:
     void changeColumnFilter(int column);
     void prioritiesChanged(QStandardItem *item);
 
-signals:
+Q_SIGNALS:
     void treeWidgetUpdated();
 
 private:
@@ -77,14 +77,14 @@ public:
     using KTreeWidgetSearchLine::updateSearch;
 
     // Reimplemented just to send a signal _AFTER_ the tree updating
-    void updateSearch(const QString &pattern = QString()) Q_DECL_OVERRIDE;
+    void updateSearch(const QString &pattern = QString()) override;
 
     void setPriorityEnabled(int priority, bool enabled);
 
 protected:
-    bool itemMatches(const QTreeWidgetItem *item, const QString &pattern) const Q_DECL_OVERRIDE;
+    bool itemMatches(const QTreeWidgetItem *item, const QString &pattern) const override;
 
-signals:
+Q_SIGNALS:
     void treeWidgetUpdated();
 
 private:
