@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _AUTHENTICATION_CONFIGURATION_WIDGET_H_
-#define _AUTHENTICATION_CONFIGURATION_WIDGET_H_
+#ifndef AUTHENTICATION_CONFIGURATION_WIDGET_H
+#define AUTHENTICATION_CONFIGURATION_WIDGET_H
 
 #include <QHBoxLayout>
 #include <QGroupBox>
@@ -48,8 +48,7 @@ public:
         : LogModeConfigurationWidget(i18n("Authentication Log"), QStringLiteral(AUTHENTICATION_MODE_ICON),
                                      i18n("Authentication Log"))
     {
-        QVBoxLayout *layout = new QVBoxLayout();
-        this->setLayout(layout);
+        QVBoxLayout *layout = new QVBoxLayout(this);
 
         warningBox = new KMessageWidget(this);
         warningBox->setVisible(false);
@@ -89,9 +88,9 @@ public:
 
     ~AuthenticationConfigurationWidget() {}
 
-public slots:
+public Q_SLOTS:
 
-    void saveConfig() Q_DECL_OVERRIDE
+    void saveConfig() override
     {
         AuthenticationConfiguration *authenticationConfiguration
             = Globals::instance()
@@ -101,7 +100,7 @@ public slots:
         authenticationConfiguration->setAuthenticationPath(authenticationUrlRequester->url().path());
     }
 
-    void readConfig() Q_DECL_OVERRIDE
+    void readConfig() override
     {
         AuthenticationConfiguration *authenticationConfiguration
             = Globals::instance()
@@ -115,14 +114,14 @@ public slots:
         authenticationUrlRequester->setUrl(QUrl::fromLocalFile(path));
     }
 
-    void defaultConfig() Q_DECL_OVERRIDE
+    void defaultConfig() override
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
 protected:
-    bool isValid() const Q_DECL_OVERRIDE
+    bool isValid() const override
     {
         if (authenticationUrlRequester->url().path().isEmpty() == false) {
             return true;
@@ -136,4 +135,4 @@ private:
     KMessageWidget *warningBox;
 };
 
-#endif // _AUTHENTICATION_CONFIGURATION_WIDGET_H_
+#endif // _AUTHENTICATION_CONFIGURATION_WIDGET_H
