@@ -88,7 +88,7 @@ protected:
         int firstPosition = cupsAccessRegex.indexIn(logLine);
         if (firstPosition == -1) {
             logDebug() << "Unable to parse line " << logLine;
-            return NULL;
+            return nullptr;
         }
 
         QStringList capturedTexts = cupsAccessRegex.capturedTexts();
