@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _XORG_ANALYZER_H_
-#define _XORG_ANALYZER_H_
+#ifndef XORG_ANALYZER_H
+#define XORG_ANALYZER_H
 
 #include <KLocalizedString>
 
@@ -41,18 +41,18 @@ class XorgAnalyzer : public FileAnalyzer
     Q_OBJECT
 
 public:
-    XorgAnalyzer(LogMode *logMode);
+    explicit XorgAnalyzer(LogMode *logMode);
 
     virtual ~XorgAnalyzer();
 
-    LogViewColumns initColumns() Q_DECL_OVERRIDE;
+    LogViewColumns initColumns() override;
 
 protected:
-    LogFileReader *createLogFileReader(const LogFile &logFile) Q_DECL_OVERRIDE;
+    LogFileReader *createLogFileReader(const LogFile &logFile) override;
 
-    Analyzer::LogFileSortMode logFileSortMode() Q_DECL_OVERRIDE;
+    Analyzer::LogFileSortMode logFileSortMode() override;
 
-    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) Q_DECL_OVERRIDE;
+    LogLine *parseMessage(const QString &logLine, const LogFile &originalFile) override;
 
 private:
     QMap<QString, LogLevel *> xorgLevels;
@@ -64,4 +64,4 @@ private:
     QDateTime currentDateTime;
 };
 
-#endif // _XORG_ANALYZER_H_
+#endif // _XORG_ANALYZER_H
