@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _X_SESSION_ITEM_BUILDER_H_
-#define _X_SESSION_ITEM_BUILDER_H_
+#ifndef X_SESSION_ITEM_BUILDER_H
+#define X_SESSION_ITEM_BUILDER_H
 
 #include <QString>
 
@@ -41,9 +41,9 @@ class XSessionItemBuilder : public LogModeItemBuilder
 public:
     XSessionItemBuilder() {}
 
-    virtual ~XSessionItemBuilder() {}
+    ~XSessionItemBuilder() override {}
 
-    void prepareItem(LogViewWidgetItem *item) const
+    void prepareItem(LogViewWidgetItem *item) const override
     {
         LogLine *line = item->logLine();
 
@@ -58,7 +58,7 @@ public:
         item->setIcon(0, QIcon(line->logLevel()->pixmap()));
     }
 
-    QString createToolTipText(LogLine *line) const
+    QString createToolTipText(LogLine *line) const override
     {
         QString result;
 
@@ -79,11 +79,11 @@ public:
         return result;
     }
 
-    QString createFormattedText(LogLine *line) const
+    QString createFormattedText(LogLine *line) const override
     {
         // It uses the same formating than the tool tip
         return createToolTipText(line);
     }
 };
 
-#endif // _X_SESSION_ITEM_BUILDER_H_
+#endif // _X_SESSION_ITEM_BUILDER_H
